==> haskell-hourglass-0.2.11-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hourglass.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hourglass
version: 0.2.11
id: hourglass-0.2.11-9hppRSjW3ll8eqnGIG01km
key: hourglass-0.2.11-9hppRSjW3ll8eqnGIG01km
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: https://github.com/vincenthz/hs-hourglass
synopsis: simple performant time related library
description:
    Simple time library focusing on simple but powerful and performant API
    .
    The backbone of the library are the Timeable and Time type classes.
    .
    Each Timeable instances can be converted to type that has a Time instances,
    and thus are different representations of current time.
category: Time
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Data.Hourglass Data.Hourglass.Compat Data.Hourglass.Epoch
    Data.Hourglass.Types System.Hourglass Time.Compat Time.System
    Time.Types
hidden-modules: Data.Hourglass.Time Data.Hourglass.Format
                Data.Hourglass.Diff Data.Hourglass.Local Data.Hourglass.Calendar
                Data.Hourglass.Zone Data.Hourglass.Internal Data.Hourglass.Utils
                Data.Hourglass.Internal.Unix
abi: e66c1bf3bb6c0e723a33754b5ad8307b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hourglass-0.2.11
library-dirs: /usr/lib/ghc-8.2.2/site-local/hourglass-0.2.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/hourglass-0.2.11
hs-libraries: HShourglass-0.2.11-9hppRSjW3ll8eqnGIG01km
depends:
    base-4.10.1.0 deepseq-1.4.3.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
haddock-interfaces: /usr/share/doc/haskell-hourglass/html/hourglass.haddock
haddock-html: /usr/share/doc/haskell-hourglass/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hourglass-0.2.11-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hourglass.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hourglass
version: 0.2.11
id: hourglass-0.2.11-6IeHxHSLI0rBEj1p6kmh6H
key: hourglass-0.2.11-6IeHxHSLI0rBEj1p6kmh6H
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: https://github.com/vincenthz/hs-hourglass
synopsis: simple performant time related library
description:
    Simple time library focusing on simple but powerful and performant API
    .
    The backbone of the library are the Timeable and Time type classes.
    .
    Each Timeable instances can be converted to type that has a Time instances,
    and thus are different representations of current time.
category: Time
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Data.Hourglass Data.Hourglass.Compat Data.Hourglass.Epoch
    Data.Hourglass.Types System.Hourglass Time.Compat Time.System
    Time.Types
hidden-modules: Data.Hourglass.Time Data.Hourglass.Format
                Data.Hourglass.Diff Data.Hourglass.Local Data.Hourglass.Calendar
                Data.Hourglass.Zone Data.Hourglass.Internal Data.Hourglass.Utils
                Data.Hourglass.Internal.Unix
abi: 0746f790d3b3c2c5d571ff9c9415ef3b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hourglass-0.2.11
library-dirs: /usr/lib/ghc-8.2.2/site-local/hourglass-0.2.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/hourglass-0.2.11
hs-libraries: HShourglass-0.2.11-6IeHxHSLI0rBEj1p6kmh6H
depends:
    base-4.10.1.0 deepseq-1.4.3.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
haddock-interfaces: /usr/share/doc/haskell-hourglass/html/hourglass.haddock
haddock-html: /usr/share/doc/haskell-hourglass/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
